<?php

namespace App\Http\Controllers\api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use DB;
use Response;
use Illuminate\Support\Facades\Validator;


class UserController extends Controller
{
    public function UserRegister(Request $request){

        $validations=([
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|unique:users',
            'number' => 'required|string|unique:users',
            'password' => 'required|string|min:6',
        ]);
        $validator = Validator::make($request->all(), $validations);
        if ($validator->fails()) {
            $response   = [
                'message' => $validator->errors($validator)->first(),
            ];
            return response()->json($response, 200);
        }
     
        $data = array(
            'name' =>$request->name,
            'email' =>$request->email,
            'number' =>$request->number,
            'password' => Hash::make($request->password),
            'main_password'=>$request->password,
            'fcm_token'=>$request->fcm_token
            
        );
       
        if(DB::table('users')->insert($data))
        {
        return response()->json(["status"=>true,'message' => 'User registered successfully', 'data' => $data], 200);
        }else{
            return response()->json(["status"=>true,'message' => 'User registered unsuccessfully'], 201);
        } 
    }

    public function UserLogin(Request $request){
        $validator= Validator::make($request->all(),[
            "email"=>"required",
            "password"=>"required",
            ]);
            if($validator->fails()){
            return Response::json(array("status"=>false,"message"=>$validator->errors()->first()));
            }
            $data=[];

            $user =DB::table("users")->select(
                "id",
                "name",
                "email",
                "number",
                "company_name",
                "company_address",
                "password",
                "fcm_token",
                "created_at",
                "updated_at"
            )
            ->where("email", $request->email)
            ->first();

        
            // $user=DB::table("user")->where(["email"=>$request->email])->first();
            
            if($user){
                if(Hash::check($request->password,$user->password)){
                    if($request->fcm_token){
                        // dd($request->all());
                        $updateToken=DB::table("users")->where(["id"=>$user->id])->update(["fcm_token"=>$request->fcm_token]);
                    }
                    $user->fcm_token = $request->fcm_token;
                    // DB::table("user")->where(["email"=>$request->email]);
                    $resultArray=["status"=>true,"data"=>$user];
                }else{
                    $resultArray=["status"=>false,"message"=>"Incorrect Password"];
                }
            }else{
                $resultArray=["status"=>false,"message"=>"Entered user email doesn't exist!"];
            }
            return response()->json($resultArray);
    }

    public function AddUserAccountOf(Request $request){
        $validations=([
            'user_id' => 'required',
            'name'=>'required|string|max:255',
        ]);
        $validator = Validator::make($request->all(), $validations);
        if ($validator->fails()) {
            $response=[
                'message'=> $validator->errors($validator)->first(),
            ];
            return response()->json($response, 400);
        }
        $user = DB::table('users')->where('id', $request->user_id)->first();

        if (!$user) {
            return response()->json(['message' => 'User not found'], 404);
        }
        $trimmedName = trim($request->name);
        $nameExists = DB::table('user_account_of')->where('name', $trimmedName)->exists();
        if ($nameExists) {
            return response()->json(['message' => 'This name is already exist Please select another name'],200); // 409 Conflict status code for conflict in resource
        }

        $data = array(
            'user_id' =>$request->user_id,
            'name' =>$trimmedName,
            'address'=>$request->address,
        );
        if(DB::table('user_account_of')->insert($data))
        {
        return response()->json(['message' => 'User Added successfully', 'data' => $data], 200);
        }else{
            return response()->json(['message' => 'Error occured enter all details carefully'], 201);
        }
    }

    public function fetchUserAccountOf(Request $request){
        $validator = Validator::make($request->all(), [
            'user_id'=>'required',
        ]);
        
        if($validator->fails()){
            return response()->json(["status" => false, "message" => $validator->errors()->first()]);
        }

        $user = DB::table('users')->where('id', $request->user_id)->first();

        if (!$user) {
            return response()->json(['message' => 'User not found'], 404);
        }
        $users= DB::table("user_account_of")->where('user_id',$request->user_id)->orderBy('user_account_of.id','DESC')->get();
        if($users){
            $resultArray=["status"=>true,"data"=>$users];
        }else{
            $resultArray=["status"=>false,"message"=>"failed to get your users list, please contact your technical support"];
        }
        return response()->json($resultArray);
    }

    public function SearchClient(Request $request){

        $query = $request->input('query');
        $posts = DB::table("user_account_of")->where('name', 'LIKE', "%$query%")
        // ->orWhere('email', 'like', "%$query%")
        ->get();

        return response()->json(['data' => $posts]);
        
    }
}
